<?php

namespace Drupal\libraries_delay_load\Controller;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Config\Entity\DraggableListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a listing of JsDelayStrategy configuration entities.
 *
 * @ingroup js_delay_strategy
 */
class JsDelayStrategyListBuilder extends DraggableListBuilder {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'js_delay_strategy';
  }

  /**
   * Builds the header row for the entity listing.
   *
   * @return array
   *   A render array structure of header strings.
   *
   * @see \Drupal\Core\Entity\EntityListController::render()
   */
  public function buildHeader() {
    $header['label'] = $this->t('Label');
    return $header + parent::buildHeader();
  }

  /**
   * Builds a row for an entity in the entity listing.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity for which to build the row.
   *
   * @return array
   *   A render array of the table row for displaying the entity.
   *
   * @see \Drupal\Core\Entity\EntityListController::render()
   */
  public function buildRow(EntityInterface $entity) {
    $row['label'] = $entity->label();
    return $row + parent::buildRow($entity);
  }

  /**
   * Adds some descriptive text to the strategy list.
   *
   * @return array
   *   Renderable array.
   */
  public function render() {

    $build['description'] = [
      '#markup' => $this->t("<p>The order of the strategies is important. The first one that validates the conditions will be applied for that page.</p>"),
    ];

    $build[] = parent::render();
    return $build;
  }

  /**
   * Invalidate necessary cache tags.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    Cache::invalidateTags(['library_info']);

    parent::submitForm($form, $form_state);
  }

}
